@@ -1,31 +1,38 @@
 import asyncio
-import ssl
+from typing import Callable, Optional
 
 import pytest
-from toolbox import ClassTask, awaitable, tls_handshake, to_thread
+from toolbox import CoroutineClass, awaitable, tls_handshake, to_thread
 
 
 class Test_patterns:
-    class CT(ClassTask):
-        def __init__(self, future: asyncio.Future, start: bool = False):
+    class CC(CoroutineClass):
+        def __init__(
+            self,
+            future: Optional[asyncio.Future] = None,
+            start_callback: Callable = lambda: print("Starting!"),
+            end_callback: Callable = lambda: print("Stopping!"),
+            run: bool = False,
+        ):
             super().__init__(
-                self.run,
-                log_start=lambda: print("Starting!"),
-                log_stop=lambda: print("Stopping!"),
-                start=start,
+                start_callback=start_callback,
+                end_callback=end_callback,
+                run=run,
             )
             self.future = future
 
-        async def run(self):
+        async def entry(self):
             await asyncio.sleep(1)
-            self.future.set_result(True)
+            if isinstance(self.future, asyncio.Future):
+                self.future.set_result(True)
+            return self.future
 
     @pytest.mark.asyncio
     async def test_start(self):
         loop = asyncio.get_event_loop()
         future = loop.create_future()
 
-        process = self.CT(future, start=True)
+        process = self.CC(future, run=True)
         assert process._task and not process._task.done()
 
         await asyncio.sleep(2)
@@ -34,12 +41,21 @@ class Test_patterns:
         process.stop()
         assert process._task and process._task.done()
 
+    @pytest.mark.asyncio
+    async def test_await(self):
+        loop = asyncio.get_event_loop()
+        future = loop.create_future()
+
+        process = self.CC(future)
+        await process
+        assert future.done() and future.result() == True
+
     @pytest.mark.asyncio
     async def test_context_manager(self):
         loop = asyncio.get_event_loop()
         future = loop.create_future()
 
-        process = self.CT(future)
+        process = self.CC(future)
         async with process as prcss:
             assert prcss._task and not prcss._task.done()
             await asyncio.sleep(2)
@@ -47,6 +63,28 @@ class Test_patterns:
 
         assert process._task and process._task.done()
 
+    @pytest.mark.asyncio
+    async def test_callbacks(self):
+        loop = asyncio.get_event_loop()
+        future = loop.create_future()
+
+        # Start callback
+        process = self.CC(future, run=future.set_result(None))
+        process.run()
+        assert future.done() and future.result() is None
+        process.stop()
+
+        # End callback.
+        future = loop.create_future()
+        process = self.CC(future, end_callback=future.set_result(None))
+        process.run()
+        process.stop()
+        assert future.done() and future.result() is None
+
+    def test_sync(self):
+        process = self.CC(future=True)
+        assert process.run() == process.result == True
+
 
 class Test_streams:
     @pytest.mark.asyncio
